@@ -579,7 +579,7 @@ TODO: there must be a better way of building up the Text
 -}
 
 singleQuoted :: N3Parser T.Text
-singleQuoted = T.pack <$> (bracket sQuot sQuot $ many n3Character)
+singleQuoted = T.pack <$> bracket sQuot sQuot (many n3Character)
     
 {-
 tripleQUoted ::=	"""[^"\\]*(?:(?:\\.|"(?!""))[^"\\]*)*"""
@@ -605,12 +605,12 @@ oneOrTwo = do
   ignore $ char '"'
   mb <- optional (char '"')
   case mb of
-    Just _ -> return $ "\"\""
-    _      -> return $ "\""
+    Just _ -> return "\"\""
+    _      -> return "\""
 
 _multiQuote :: N3Parser T.Text
 _multiQuote = do
-  mq <- optional (oneOrTwo)
+  mq <- optional oneOrTwo
   r <- noneOf "\"\\"
   return $ fromMaybe T.empty mq `T.snoc` r
                 
